@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ansi" "0.4.1"
+(define-package "ansi" "20251118.230"
   "Turn string into ansi strings."
-  '((s    "1.6.1")
-    (dash "1.5.0"))
+  '((emacs  "24.1")
+    (cl-lib "0.6"))
   :url "http://github.com/rejeep/ansi"
-  :commit "a042c5954453bab9a74177e2b78ad17a824caebc"
-  :revdesc "a042c5954453"
-  :keywords '("color" "ansi")
+  :commit "a3aa9daa37a75fec22186399014a790a6c554311"
+  :revdesc "a3aa9daa37a7"
+  :keywords '("terminals" "color" "ansi")
   :authors '(("Johan Andersson" . "johan.rejeep@gmail.com"))
   :maintainers '(("Johan Andersson" . "johan.rejeep@gmail.com")))
